from typing import Union

from litellm import completion, ModelResponse, CustomStreamWrapper


class LLMConfig:
    """
    Configuration for the LLM, including model details and additional parameters.
    """

    def __init__(self, model: str, **kwargs):
        """
        Initializes the LLMConfig with a model name and additional parameters.

        Args:
            model (str): The name of the model (e.g., "gemini/gemini-exp-1206").
            **kwargs: Additional parameters for the completion function.
        """
        self.model = model
        self.kwargs = kwargs

    def completion(self, **additional_kwargs) -> Union[ModelResponse, CustomStreamWrapper]:
        """
        Calls the completion function from liteLLM with combined parameters.

        Args:
            **additional_kwargs: Additional parameters to pass to the completion function.

        Returns:
            Union[ModelResponse, CustomStreamWrapper]: The response generated by the model.
        """
        # Combine the stored kwargs with additional parameters
        combined_kwargs = self.kwargs.copy()
        combined_kwargs.update(additional_kwargs)

        return completion(model=self.model, **combined_kwargs)
